@@ -1,7 +1,6 @@
 from .temp_mail import *
 from .temp_phone import ReceiveSms
-from .fake_data import Person
-from .fake_data.personcounties import PersonCounties
+from .fake_data import generate_person, generate_persons
 from .fake_data.utilities import get_password
 from .proxies import Proxies, ProxyType
 from .countries import Counties
@@ -10,4 +9,4 @@ from .captcha_solver import CaptchaSolver
 
 __author__ = 'Dionis1902'
 __email__ = 'den70007.ua@gmail.com'
-__version__ = '1.0.10'
+__version__ = '1.0.11'
